@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.21';
+our $VERSION = '0.2.22';
 
 1;
 
@@ -162,8 +162,9 @@ sub run_story_file {
     my $story_dir = get_prop('story_dir');
 
     my $cwd_size = scalar(split /\//, get_prop('project_root_dir'));
+    my $task_name = get_prop('task_name');
 
-    note("\n". ( nocolor() ? short_story_name() : colored(['yellow'],short_story_name()) )." started");
+    note("\n". ( nocolor() ? $task_name.short_story_name() : colored(['yellow'],$task_name.short_story_name()) )." started");
 
     if ( get_stdout() ){
 
